@@ -72,7 +72,7 @@
 ;; (autoload 'ess-switch-process           "ess-inf" "" nil)
 ;; (autoload 'ess-switch-to-ESS            "ess-inf" "" nil)
 ;; (autoload 'ess-request-a-process        "ess-inf" "" nil)
-;; (autoload 'get-ess-process              "ess-inf" "" nil)
+;; (autoload 'ess-get-process              "ess-inf" "" nil)
 ;; (autoload 'ess-command                  "ess-inf" "" nil)
 ;; (autoload 'ess-create-temp-buffer       "ess-inf" "" nil)
 ;; (autoload 'ess-display-temp-buffer      "ess-inf" "" nil)
@@ -201,10 +201,11 @@
     (define-key ess-extra-map "l" 'ess-load-library)
     (define-key ess-extra-map "\C-i" 'ess-install-library)
     (define-key ess-extra-map "i" 'ess-install-library)
-    ;; (define-key map "C-t" 
+    (define-key ess-extra-map "\C-w" 'ess-execute-screen-options)
+    (define-key ess-extra-map "w" 'ess-execute-screen-options)
+    ;; (define-key map "C-t"
     ess-extra-map)
-  "ESS extra map"
-  )
+  "ESS extra map")
 
 
 (require 'ess-noweb-mode)
@@ -454,36 +455,12 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
   (make-local-variable 'indent-tabs-mode)
   (setq indent-tabs-mode nil)
 
-  ;;  (make-local-variable 'paragraph-start)
-  ;;  (setq paragraph-start (concat "^$\\|" page-delimiter))
-  ;;  (make-local-variable 'paragraph-separate)
-  ;;  (setq paragraph-separate paragraph-start)
-  ;;  (make-local-variable 'paragraph-ignore-fill-prefix)
-  ;;  (setq paragraph-ignore-fill-prefix t)
-  ;;  (make-local-variable 'indent-line-function)
-  ;;  (setq indent-line-function 'ess-indent-line)
-  ;;  (make-local-variable 'require-final-newline)
-  ;;  (setq require-final-newline t)
-  ;;  (make-local-variable 'comment-start)
-  ;;  (setq comment-start "#")
-  ;;  (make-local-variable 'comment-start-skip)
-  ;;  (setq comment-start-skip "#+ *")
-  ;;  (make-local-variable 'comment-column)
-  ;;  (setq comment-column 40)
-  ;;  (make-local-variable 'comment-indent-function)
-  ;;  (setq comment-indent-function 'ess-comment-indent)
-  ;;  (make-local-variable 'parse-sexp-ignore-comments)
-  ;;  (setq parse-sexp-ignore-comments t)
-  ;;  (ess-set-style ess-default-style)
-  ;;  (make-local-variable 'ess-local-process-name)
-  ;;  (make-local-variable 'ess-keep-dump-files)
-
   (put 'ess-local-process-name 'permanent-local t) ; protect from RCS
-  (if (featurep 'xemacs)
-      (setq mode-line-process ;; AJR: in future, XEmacs will use modeline-process.
-            '(" [" ess-local-process-name  "]")) ;; xemacs does not support :eval
-    (setq mode-line-process
-          '(" [" (:eval (ess--get-mode-line-indicator))  "]")))
+  (setq mode-line-process
+        '(" ["
+          (:eval (ess--get-mode-line-indicator))
+          ess--local-mode-line-process-indicator
+          "]"))
   ;; completion
   (if (and (featurep 'emacs)
            (>= emacs-major-version 24))
@@ -507,14 +484,14 @@ indentation style. At present, predefined style are `BSD', `GNU', `K&R', `C++',
 
 
 (defun ess--get-mode-line-indicator ()
-  "Get `ess-mode-line-indicator' from process buffer.
+  "Get `ess--mode-line-process-indicator' from process buffer.
 Internal function to be used for dynamic mode-line dysplay in
 ess-mode."
   (if ess-local-process-name
       (let* ((proc (get-process ess-local-process-name))
-             (buff (if proc (process-buffer proc))))
+             (buff (when proc (process-buffer proc))))
         (if (and proc (buffer-live-p buff))
-            (with-current-buffer buff (mapcar 'eval ess-mode-line-indicator))
+            (with-current-buffer buff (mapcar 'eval ess--mode-line-process-indicator))
           "none"))
     "none"))
 
@@ -613,6 +590,11 @@ it cannot find a function beginning."
     (if (search-forward "("
                         (ess-line-end-position 2) t); at most end of next line
         (forward-char 1))
+    ;; TODO: replace the above by hopefully more sucessful logic:
+    ;; 1. If we have 'function *(' in the same line, move to end of that line
+    ;; 2. if *not*, skip all comment lines (concat space comment-char .* "\n")
+    ;;    and only* then do something like the
+    ;;    (search-forward '(' .. (..line-end.. 2) )  above
 
     (setq end (point)); = init-point when nothing found
 
@@ -927,31 +909,34 @@ of the expression are preserved."
 
 
 (defun ess-indent-or-complete ()
-  "Try to indent first, if code is already properly indented, complete instead.
-It calls `comint-dynamic-complete' for emacs < 24 and `completion-at-point' otherwise.
+  "When region is selected indent the region, otherwise, if
+`ess-tab-complete-in-script' is non-nil, try to indent, if code
+is already indented, complete instead.
 
-In ess-mode, only tries completion if `ess-tab-complete-in-script' is non-nil.
-See also `ess-first-tab-never-complete'."
+The default of `ess-tab-complete-in-script' is nil.  Also see
+`ess-first-tab-never-complete'."
   (interactive)
-  (let ((shift (ess-indent-command)))
-    (when (and ess-tab-complete-in-script
-               (numberp shift) ;; can be nil if ess-tab-always-indent is nil
-               (equal shift 0)
-               (or (eq last-command 'ess-indent-or-complete)
-                   (null ess-first-tab-never-complete)
-                   (and (eq ess-first-tab-never-complete 'unless-eol)
-                        (looking-at "\\s-*$"))
-                   (and (eq ess-first-tab-never-complete 'symbol)
-                        (not (looking-at "\\w\\|\\s_")))
-                   (and (eq ess-first-tab-never-complete 'symbol-or-paren)
-                        (not (looking-at "\\w\\|\\s_\\|\\s)")))
-                   (and (eq ess-first-tab-never-complete 'symbol-or-paren-or-punct)
-                        (not (looking-at "\\w\\|\\s_\\|\\s)\\|\\s.")))
-                   ))
-      (if (and (featurep 'emacs) (>= emacs-major-version 24))
-          (completion-at-point)
-        (comint-dynamic-complete)
-        ))))
+  (if (use-region-p)
+      (indent-region (region-beginning) (region-end))
+    (let ((shift (ess-indent-command)))
+      (when (and ess-tab-complete-in-script
+                 (numberp shift) ;; can be nil if ess-tab-always-indent is nil
+                 (equal shift 0)
+                 (or (eq last-command 'ess-indent-or-complete)
+                     (null ess-first-tab-never-complete)
+                     (and (eq ess-first-tab-never-complete 'unless-eol)
+                          (looking-at "\\s-*$"))
+                     (and (eq ess-first-tab-never-complete 'symbol)
+                          (not (looking-at "\\w\\|\\s_")))
+                     (and (eq ess-first-tab-never-complete 'symbol-or-paren)
+                          (not (looking-at "\\w\\|\\s_\\|\\s)")))
+                     (and (eq ess-first-tab-never-complete 'symbol-or-paren-or-punct)
+                          (not (looking-at "\\w\\|\\s_\\|\\s)\\|\\s.")))
+                     ))
+        (if (and (featurep 'emacs) (>= emacs-major-version 24))
+            (completion-at-point)
+          (comint-dynamic-complete)
+          )))))
 
 (defun ess-indent-exp ()
   "Indent each line of the ESS grouping following point."
@@ -1412,7 +1397,7 @@ generate the source buffer."
   (let* ((dirname (file-name-as-directory
                    (if (stringp ess-source-directory)
                        ess-source-directory
-                     (with-current-buffer (process-buffer (get-ess-process
+                     (with-current-buffer (process-buffer (ess-get-process
                                                            ess-local-process-name))
                        (ess-setq-vars-local ess-customize-alist)
                        (apply ess-source-directory nil)))))
