@@ -800,22 +800,25 @@ optional argument is non-nil, then set-buffer rather than switch."
   "And now for something completely different."
   (interactive)
   (ess-sas-file-path)
-
+  (setq ess-customize-alist SAS-customize-alist)
   (let ((ess-temp-sas-file
          (nth 0 (split-string
                  (car (last (split-string ess-sas-file-path "\\([a-zA-Z][a-zA-Z]:\\|]\\)"))) "[.]"))))
     ;;    (message "%s" ess-temp-sas-file)
     (setq ess-sas-shell-buffer "*iESS[SAS]*")
     (ess-sas-goto-shell)
-    (insert (concat ess-sas-submit-command " " ess-sas-submit-command-options
-                    " -altlog " ess-temp-sas-file ".log -altprint "
-                    ess-temp-sas-file ".lst -stdio < /dev/tty"))
-    (comint-send-input)
     (ess-add-ess-process)
+    (ess-setq-vars-local ess-customize-alist)
+    (inferior-ess-mode)
+    (ess-eval-linewise (concat ess-sas-submit-command " " ess-sas-submit-command-options
+                               " -altlog " ess-temp-sas-file ".log -altprint "
+                               ess-temp-sas-file ".lst -stdio"))
+                               ;;ess-temp-sas-file ".lst -stdio < /dev/tty"))
     (ess-sas-goto-sas)
     (setq ess-sas-submit-method 'iESS)
     (setq ess-eval-visibly-p nil)
     ))
+
 ;;(defun ess-sas-interactive ()
 ;;    (interactive)
 ;;    (ess-sas-file-path)
