@@ -187,7 +187,8 @@ Better logic needed!  (see 2 uses, in this file).")
     (inferior-ess-start-args       . inferior-SAS-args-temp)
     (inferior-ess-font-lock-defaults . SAS-mode-font-lock-defaults)
     ;; (ess-pre-run-hook              . 'ess-SAS-pre-run-hook)
-    (ess-local-process-name        . nil))
+    ;; (ess-local-process-name        . nil)
+    )
   "Variables to customize for SAS")
 
 ;;; The functions of interest (mode, inferior mode)
@@ -244,7 +245,7 @@ Better logic needed!  (see 2 uses, in this file).")
 
 ;; rmh Jul 10 2003
 (defun ess-electric-run-semicolon (arg)
-  "Insert character.  If the line contains \"run;\" and nothing else then indent line."
+  "Insert character.  If the line contains \"run;\" or \"quit;\" and nothing else then indent line."
   (interactive "P")
   (if ess-sas-edit-keys-toggle (insert ";") (let (insertpos)
                                               (if (and (not arg)
@@ -252,7 +253,7 @@ Better logic needed!  (see 2 uses, in this file).")
                                                        (save-excursion
                                                          (skip-chars-backward " \t")
                                                          (backward-word 1)
-                                                         (and (looking-at "run")
+                                                         (and (looking-at "run\\|quit")
                                                               (progn
                                                                 (skip-chars-backward " \t")
                                                                 (bolp)))))
