@@ -27,11 +27,11 @@
 
 ;;; Commentary:
 
-;; This file defines all the site-specific customizations for ESS. It should be
-;; edited on a per-site basis. Read the comments (1.1 in Section 1 to see if
-;; ess-site.el must be edited. The final directory location of this file must be
-;; supplied in ess-lisp-directory. The editing of remaining sections is
-;; optional. It should then be byte-compiled, and users who wish to use ESS
+;; This file defines all the site-specific customizations for ESS.  It should be
+;; edited on a per-site basis.  Read the comments (1.1 in Section 1 to see if
+;; ess-site.el must be edited.  The final directory location of this file must be
+;; supplied in ess-lisp-directory.  The editing of remaining sections is
+;; optional.  It should then be byte-compiled, and users who wish to use ESS
 ;; should add the line:
 ;;
 ;;    (load "/PATH/TO/THIS/FILE/ess-site")
@@ -155,13 +155,13 @@ The extension, in a file name, is the part that follows the last `.'."
 ;; depends on ess-lisp-directory, and is needed by other modes that are
 ;; loaded before the custom code.
 (defvar ess-etc-directory nil
-  "*Location of the ESS etc/ directory.
+  "Location of the ESS etc/ directory.
 The ESS etc directory stores various auxillary files that are useful
 for ESS, such as icons.")
 
 (defvar ess-etc-directory-list
   '("../etc/ess/" "../etc/" "../../etc/ess/" "./etc/")
-  "*List of directories, relative to `ess-lisp-directory', to search for etc.")
+  "List of directories, relative to `ess-lisp-directory', to search for etc.")
 
 (while (and (listp ess-etc-directory-list) (consp ess-etc-directory-list))
   (setq ess-etc-directory
@@ -215,15 +215,27 @@ for ESS, such as icons.")
 
 (autoload 'Rd-mode "ess-rd" "Major mode for editing R documentation." t)
 
+; Here is a workaround for an Emacs bug related to indirect buffers and 
+; spurious lockfiles that rears its ugly head with .Rd files
+; http://lists.gnu.org/archive/html/bug-gnu-emacs/2013-02/msg01368.html
+; http://debbugs.gnu.org/cgi/bugreport.cgi?bug=14328
+(if (featurep 'xemacs) nil
+  ;; (add-hook 'Rd-mode-hook (lambda () 
+  ;;         (set (make-local-variable create-lockfiles) nil)))
+					
+  (make-local-variable 'create-lockfiles)
+
+  (add-hook 'Rd-mode-hook (lambda () (setq create-lockfiles nil))) 
+)
+
 ;; This is thanks to  Ed L Cashin <ecashin@uga.edu>, 03 Mar 2004 :
 (defun ess-restore-asm-extns ()
-  "take away the S-Plus mode association for .s and .S files added by ESS
+  "Remove the S-Plus mode association for .s and .S files added by ESS.
 Putting the following in ~/.emacs restores emacs' default association
 between .s or .S files and assembly mode.
 
   (add-hook 'ess-mode-hook 'ess-restore-asm-extns)
-  (add-hook 'inferior-ess-mode-hook 'ess-restore-asm-extns)
-"
+  (add-hook 'inferior-ess-mode-hook 'ess-restore-asm-extns)"
   (interactive)
   (when (assoc "\\.[qsS]\\'" auto-mode-alist)
     (setq auto-mode-alist
@@ -396,24 +408,24 @@ sending `inferior-ess-language-start' to S-Plus.")
 
 (if ess-microsoft-p
     (progn
-      (ess-message "[ess-site:] require 'ess-sp4-d ...")
-      (require 'ess-sp4-d)
+      ;; (ess-message "[ess-site:] require 'ess-sp4-d ...")
+      ;; (require 'ess-sp4-d)
       (ess-message "[ess-site:] require 'ess-sp6w-d ...")
       (require 'ess-sp6w-d))
   ;; else: decent OS
-  (ess-message "[ess-site:] require 'ess-sp5-d ...")
-  (require 'ess-sp5-d)
+  ;; (ess-message "[ess-site:] require 'ess-sp5-d ...")
+  ;; (require 'ess-sp5-d)
   (ess-message "[ess-site:] require 'ess-sp6-d ...")
   (require 'ess-sp6-d))
 
 (ess-message "[ess-site:] require 'ess-sta-d ...")
 (require 'ess-sta-d)  ;; for Stata.
-(ess-message "[ess-site:] require 'ess-xls-d ...")
-(require 'ess-xls-d)  ;; XLispStat
-(ess-message "[ess-site:] require 'ess-vst-d ...")
-(require 'ess-vst-d)  ;; ViSta
-(ess-message "[ess-site:] require 'ess-arc-d ...")
-(require 'ess-arc-d)  ;; Arc
+;; (ess-message "[ess-site:] require 'ess-xls-d ...")
+;; (require 'ess-xls-d)  ;; XLispStat
+;; (ess-message "[ess-site:] require 'ess-vst-d ...")
+;; (require 'ess-vst-d)  ;; ViSta
+;; (ess-message "[ess-site:] require 'ess-arc-d ...")
+;; (require 'ess-arc-d)  ;; Arc
 (ess-message "[ess-site:] require 'ess-sas-d ...")
 (require 'ess-sas-d)
 (ess-message "[ess-site:] require 'essd-els ...")
@@ -512,11 +524,11 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;;; Create functions for calling different (older or newer than default)
 ;;;  versions of R and S(qpe).
 (defvar ess-versions-created nil
-  "list of strings of all S- and R-versions found on the current computer environment")
+  "List of strings of all S- and R-versions found on the system.")
 
 ;; is currently used (updated) by ess-find-newest-R
 (defvar ess-r-versions-created nil
-  "list of strings of all R-versions found on the current computer environment")
+  "List of strings of all R-versions found on the system.")
 ;; FIXME: should then update ess-versions-created as well (easy),
 ;; -----  *and* update the "Start Process" menu (below)
 ;;    -> To this: wrap the following in functions that can be re-called
@@ -526,66 +538,66 @@ sending `inferior-ess-language-start' to S-Plus.")
 The extension, in a file name, is the part that follows the last `.'."
 
   (interactive)
-(ess-message "[ess-site:] before creating ess-versions-* ...")
-;; Create  ess-versions-created,
-;;         ess-r-versions-created,
-;; and on Windows, ess-rterm-version-paths -----------------------------------------
-(let ((R-newest-list '("R-newest"))
-      (ess-s-versions-created (if ess-microsoft-p
-                                  (nconc
-                                   (ess-sqpe-versions-create ess-SHOME-versions)               ;; 32-bit
-                                   (ess-sqpe-versions-create ess-SHOME-versions-64 "-64-bit")) ;; 64-bit
-                                (ess-s-versions-create)))) ;; use ess-s-versions
-  (if ess-microsoft-p
-      (setq ess-rterm-version-paths ;; (ess-find-rterm))
-            (ess-flatten-list
-             (ess-uniq-list
-              (if (not ess-directory-containing-R)
-                  (if (getenv "ProgramW6432")
-                      (let ((P-1 (getenv "ProgramFiles(x86)"))
-                            (P-2 (getenv "ProgramW6432")))
+  (ess-message "[ess-site:] before creating ess-versions-* ...")
+  ;; Create  ess-versions-created,
+  ;;         ess-r-versions-created,
+  ;; and on Windows, ess-rterm-version-paths -----------------------------------------
+  (let ((R-newest-list '("R-newest"))
+        (ess-s-versions-created (if ess-microsoft-p
+                                    (nconc
+                                     (ess-sqpe-versions-create ess-SHOME-versions)               ;; 32-bit
+                                     (ess-sqpe-versions-create ess-SHOME-versions-64 "-64-bit")) ;; 64-bit
+                                  (ess-s-versions-create)))) ;; use ess-s-versions
+    (if ess-microsoft-p
+        (setq ess-rterm-version-paths ;; (ess-find-rterm))
+              (ess-flatten-list
+               (ess-uniq-list
+                (if (not ess-directory-containing-R)
+                    (if (getenv "ProgramW6432")
+                        (let ((P-1 (getenv "ProgramFiles(x86)"))
+                              (P-2 (getenv "ProgramW6432")))
+                          (nconc
+                           ;; always 32 on 64 bit OS, nil on 32 bit OS
+                           (ess-find-rterm (concat P-1 "/R/") "bin/Rterm.exe")
+                           (ess-find-rterm (concat P-1 "/R/") "bin/i386/Rterm.exe")
+                           ;; keep this both for symmetry and because it can happen:
+                           (ess-find-rterm (concat P-1 "/R/") "bin/x64/Rterm.exe")
+
+                           ;; always 64 on 64 bit OS, nil on 32 bit OS
+                           (ess-find-rterm (concat P-2 "/R/") "bin/Rterm.exe")
+                           (ess-find-rterm (concat P-2 "/R/") "bin/i386/Rterm.exe")
+                           (ess-find-rterm (concat P-2 "/R/") "bin/x64/Rterm.exe")
+                           ))
+                      (let ((PF (getenv "ProgramFiles")))
                         (nconc
-                         ;; always 32 on 64 bit OS, nil on 32 bit OS
-                         (ess-find-rterm (concat P-1 "/R/") "bin/Rterm.exe")
-                         (ess-find-rterm (concat P-1 "/R/") "bin/i386/Rterm.exe")
-                         ;; keep this both for symmetry and because it can happen:
-                         (ess-find-rterm (concat P-1 "/R/") "bin/x64/Rterm.exe")
-
-                         ;; always 64 on 64 bit OS, nil on 32 bit OS
-                         (ess-find-rterm (concat P-2 "/R/") "bin/Rterm.exe")
-                         (ess-find-rterm (concat P-2 "/R/") "bin/i386/Rterm.exe")
-                         (ess-find-rterm (concat P-2 "/R/") "bin/x64/Rterm.exe")
+                         ;; always 32 on 32 bit OS, depends on 32 or 64 process on 64 bit OS
+                         (ess-find-rterm (concat PF "/R/") "bin/Rterm.exe")
+                         (ess-find-rterm (concat PF "/R/") "bin/i386/Rterm.exe")
+                         (ess-find-rterm (concat PF "/R/") "bin/x64/Rterm.exe")
                          ))
-                    (let ((PF (getenv "ProgramFiles")))
-                      (nconc
-                       ;; always 32 on 32 bit OS, depends on 32 or 64 process on 64 bit OS
-                       (ess-find-rterm (concat PF "/R/") "bin/Rterm.exe")
-                       (ess-find-rterm (concat PF "/R/") "bin/i386/Rterm.exe")
-                       (ess-find-rterm (concat PF "/R/") "bin/x64/Rterm.exe")
-                       ))
-                    )
-                (let ((PF ess-directory-containing-R))
-                  (nconc
-                   (ess-find-rterm (concat PF "/R/") "bin/Rterm.exe")
-                   (ess-find-rterm (concat PF "/R/") "bin/i386/Rterm.exe")
-                   (ess-find-rterm (concat PF "/R/") "bin/x64/Rterm.exe")
-                   ))
-                )))))
-  (ess-message "[ess-site:] (let ... before (ess-r-versions-create) ...")
+                      )
+                  (let ((PF ess-directory-containing-R))
+                    (nconc
+                     (ess-find-rterm (concat PF "/R/") "bin/Rterm.exe")
+                     (ess-find-rterm (concat PF "/R/") "bin/i386/Rterm.exe")
+                     (ess-find-rterm (concat PF "/R/") "bin/x64/Rterm.exe")
+                     ))
+                  )))))
+    (ess-message "[ess-site:] (let ... before (ess-r-versions-create) ...")
 
-  (setq ess-r-versions-created ;;  for Unix *and* Windows, using either
-        (ess-r-versions-create));; ess-r-versions or ess-rterm-version-paths (above!)
+    (setq ess-r-versions-created ;;  for Unix *and* Windows, using either
+          (ess-r-versions-create));; ess-r-versions or ess-rterm-version-paths (above!)
 
-  ;; Add the new defuns, if any, to the menu.
-  ;; Check that each variable exists, before adding.
-  ;; e.g. ess-sqpe-versions-created will not be created on Unix.
-  (setq ess-versions-created
-        (ess-flatten-list
-         (mapcar (lambda(x) (if (boundp x) (symbol-value x) nil))
-                 '(R-newest-list
-                   ess-r-versions-created
-                   ess-s-versions-created)))))
-)
+    ;; Add the new defuns, if any, to the menu.
+    ;; Check that each variable exists, before adding.
+    ;; e.g. ess-sqpe-versions-created will not be created on Unix.
+    (setq ess-versions-created
+          (ess-flatten-list
+           (mapcar (lambda(x) (if (boundp x) (symbol-value x) nil))
+                   '(R-newest-list
+                     ess-r-versions-created
+                     ess-s-versions-created)))))
+  )
 
 (ess-message "[ess-site:] before (ess-r-s-versions-creation) ...")
 (ess-r-s-versions-creation)
